function [nos,max_dt_pr,t,dt]=chk_nos(dt0,t_mult,T,max_dt)
% calculate the number of time steps in a simulation
% note that there are nos+1 time points !
% Input:
% dt0 - the initial time step length
% t_mult - the multiplier of time step length
% T -  maximum time in the simulation 
% max_dt - maximum allowable time step length
%
% Output:
% nos - number of time steps
% max_dt_pr - the maximum time step in the simulation
% t - a vector of length nos+1. 
%            contains the discrete values of time that are to be simulated.
% dt - time step size (vector of nos length)

% data check
if t_mult<1
    error('t_mult must be >=1')
end
if max_dt>T
    warning('please note that max_dt>T')
end
if dt0>T
    warning('please note that dt0>T')
end
% initialize variables
t=0;
n=0;
delta_t=dt0;
max_dt_pr=delta_t;
 
%loop to calculate
while t<T
    t=t+delta_t; % at the end of the timestep  
    n=n+1; % at the end of the time step
    
    % In the simulation file, here come calculations of current time step
    %and then...
    delta_t=min(delta_t*t_mult,max_dt); % for the next time step
    max_dt_pr=max(max_dt_pr,delta_t);
end
% the current value of n is "nos"
nos=n;

delta_t=dt0;
t=zeros(nos,1);
for i=2:nos+1
    t(i)=t(i-1)+delta_t;
    delta_t=min(delta_t*t_mult,max_dt);
end
dt=diff(t);