% main function for simulating reactive diffusive system

%% acquire data and initialize variables
clear,clc, figure(1),clf, figure(2),clf
set(0,'defaulttextinterpreter','tex')
tic
[av,d,Nsim,D,Kf,C_0,omega,N_0,alpha,T,...
          t_mult,dt0,max_dt,nos,t,dt,mp0]=set_run_parameters;
% get random seed values for random number generation for all simulations
rng('shuffle')
% 'av' struct contains Administrative Variables for the simulation
av.seeds=randi(2^32,[1 Nsim]); % random integers between 1 to 2^32

%% prepare to run simulations
if matlabpool('size')>0 && (Nsim==1) % if matlabpool workers are not nessecery
    matlabpool close                 % close them 
end

% the loop can be either "parfor" loop if we want to use parallel computing, or
% "for" loop if we want single core computing (when Nsim=1; mainly used for debugging)
if Nsim>1
    loop_str='matlabpool open; parfor';
else
    loop_str='for';
end
loop_str=[loop_str ...
    ' sim=1:Nsim,'...
        'seed_val=av.seeds(sim);'...
        '[c_all{sim},sumpr{sim}]=rw_realization(av,d,Nsim,D,Kf,C_0,omega,N_0,alpha,'...
        'nos,t,dt,mp0,sim,seed_val);'...
    'end']; %  for/parfor loop
%% run simulations:
eval(loop_str)  % this calls the rw_realization function Nsim times
av.matlabpool_size=matlabpool('size');
%% close workers (if open) and save
if Nsim>1
    matlabpool close
end
disp('All the realizations completed running')
save(av.master_results_file_name) 
disp(['Saved results data to ' av.master_results_file_name])

%% calculate ensemble
disp('Calculating ensembles...')
%initialize the variable used to store cumulative results
c=zeros(nos+1,1);   % the average concentration in space, as function of time, <c(t)>
for sim=1:Nsim  % given by the average:
    c = c + c_all{sim}/Nsim; % by adding up all simulated values and taking ensemble average
end

%% plot the ensemble results
if av.plot_conc
    fig_num=2;
    disp('Plotting average concentration vs. time...')
    det_kappa=zeros(nos,1);
    for i=1:nos
        det_kappa(i)=det(kappa(alpha,D,dt(i),d));
    end
    plot_concT(t, c_all, c, N_0,d,T, Nsim,alpha,D,Kf,C_0,omega,det_kappa,fig_num)
end
%% calculate time of simulation and exit
av.total_time=toc;
disp(['The run took ' num2str(av.total_time) ' [sec], i.e. ' ...
       num2str(av.total_time/3600) ' [hr] to complete.' ])

save(av.master_results_file_name) 
disp(['Saved results data to ' av.master_results_file_name])

disp('Run finished, without error!')
diary off % stop sending the Command window output into the log file

