function [C,time_line]=numerical_solution(chi_star,tspan,d)
% We solve here the exact equation for one-dimensional problem
%   (exact, except the drop of 3rd moments).
% We do it numerically, by ode45 function.
% Input includes:
% alpha - the differentiation paramter
% chi_star - the parameter representing the intial condition
% some arbitrary initial N.D. time t_0 (should be small)
% and tspan - a N.D.(NON-DIMENSIONAL) time vector.
% the result is C(t). also non dimensional !!

m=chi_star/2; %chi_star=omega^d/N/(8*pi*D)^(d/2)*(Kf*C_initial)^(d/2)
if d==2 && m>=1 
    error('value of chi_star too large. analytical solution not valid')
end
t0=tspan(1);
y0=[1/(1+t0) log(1+t0)]; % the initial condition for y(1),y(2)
options = odeset('RelTol',1e-4,'AbsTol',1e-20,'MaxStep',tspan(end)/100); %default is 1e-3
% [time_line,Y]=ode15s(@(t,y) odefun(t,y,m,d),tspan,y0,options);
[time_line,Y]=ode15s(@(t,y) odefun(t,y,m,d),tspan,y0,options);
C=Y(:,1);



function dy=odefun(t,y,m,d)
    dy=zeros(2,1);
    dy(1)= -y(1)^2+m*(t^(-d/2))*(1-exp(-4*y(2))); % derivative dc/dt
    if m*(t^(-d/2))*(1-exp(-4*y(2)))<0
        disp(t) 
        warning ('AP:2nd term in RHS is negative')
    end
    if dy(1)>0
        disp(t) 
        disp(-y(1)^2)
        disp(dy(1))
        warning ('AP:RHS is positive; correcting to 0')
        dy(1)=0; 
    end
    if y(1)>1
        warning('AP:concentration exceeding 1')
        disp(y(1))
    end
    dy(2)=  y(1);  % y(2) is integral over concentration
