function  plot_concT(t1,c_all1,c1,N_0,d,T1,Nsim,alpha,D,Kf,C_0,omega,det_kappa,fig_num)
%% calculate exact solution
%we assume here: (sigma/C_initial)^2*(l^d)=omega^d/N_0;
Da=Kf*C_0/D*(omega/N_0^(1/d))^2;
chi_star=(Da/(8*pi))^(d/2);
% t_0ND=chi_star^(2/d)+0.001;
% t_span=logspace(log10(t_0ND),log10(time_lineND(end)),400);
% exact=exact_solution_w_Bessel_functions(2/d,chi_star,t_0ND,t_span); % alpha=2/d since 1/alpha=d/2
% t_span=logspace(-6,log10(time_lineND(end)),400);
t=t1*Kf*C_0; %non dimensional time
T=T1*Kf*C_0; %non dimensional (final) time 
alpha_star=alpha/(Kf*C_0); % non dimensional shear rate
t_span=[10^-3,t(end)];
c=c1/C_0;
[c_num,ntl]=numerical_solution(chi_star,t_span,d); 
  % ntl = numerical time line; time line corresonding c_num
  % NOTE that sometime the numerical solution may give erroneous results
if fig_num~=0
  figure(fig_num)
end % if fig_num is 0 the plot will be done in the current plot

%subplot 211

% time vector for calculating the thermodynamic limit
log_tl=logspace(log10(t(2)),log10(max(t)),100);

% expectation of amount of particles within ellipse (assuming: well mixed)
% dt=diff(t);
% k11k22=dt*0; %initialize with zeros
% for i=1:length(c)-1
%     k=kappa_nd(alpha_star,Da,dt(i)); 
%     k11k22(i)=k(1,1)*k(2,2);    
% end

R=sqrt(det_kappa)/omega*N_0^(1/d);

h=loglog(log_tl,(1+log_tl).^-1,...
    t(1),c(1),'rs',  ntl,c_num,'k', t(2:end),R);
if fig_num~=0    
    set(h,'MarkerSize',4,'LineWidth',2)
    xlabel('Non Dimensional Time (C_0K_ft)')
    ylabel('<C_A>/C_0') %,'Interpreter','Tex'
    str{1}='Well mixed solution';
    str{2}='model results';    
    str{3}='Appr. analytical sol.';
    str{4}='det(\kappa)^{1/2}/\Omega N_0^{1/d}';
    legend(str,'Interpreter','Tex','Location','SouthWest')
end

t_aid=logspace(log10(T)-3,log10(T)); % time values for the t^-d/4 line in figure
fctr=0.05; % an arbitrary factor
y=fctr*(t_aid.^(-d/4));

hold on, plot(t_aid,y,'k--')

if iscell(c_all1)
    c_all=cell2mat(c_all1)/C_0;
    plot(t,c_all);
end
plot(t,c,'-rs')
t_bnd=Da/64*N_0^(2/d); % approximate time where boundary effects kick in
plot( t_bnd *[1 1],[c(end) c(1)],'--k')
text(t_bnd,c(end)*50,'t*_{bnd}')

hold off

switch d
    case 1 , txt='1/4';
    case 2 , txt='1/2';
    case 3 , txt='3/4';
end
if fig_num~=0
    text(t_aid(end),y(end),['slope=-' txt])
    text(2,0.8,['d= ' num2str(d) ],'Interpreter','none')
    text(2,0.4,['Nsim= ' num2str(Nsim) ',  \alpha^*= ' num2str(alpha_star) ]) 
    text(2,0.2,['N_0=' num2str(N_0) ])
    text(2,0.07,[' Da=' num2str(Da) ', t*_{max}=' num2str(T) ])

end
grid
set(gca,'gridLineStyle','-','minorGridLineStyle','none')
set(gca,'xlim',[10^floor(log10(t(2))) Inf])




%{
% to plot all simulations, use :
hold on
for i=1:Nsim
    plot(time_line1{i}*Kf*C_initial,nA1{i}/N)
end
hold off
% to plot R for all simulations, use:
hold on
for i=1:Nsim, 
    t=time_line1{i};
    n=nA1{i};
    R=(n(1:end-1)).^(1/d).*sqrt(2*D*diff(t))/omega; 
    plot(t(1:end-1)*2,R)
end
hold off
%}
