function dx=random_walk(kappa,NA,d)
% calculates a random walk for shear flow.
% INPUT: kappa- kappa matrix (dimensional)
%        NA - number of particles that march
% OUTPUT: dx  the Nxd matrix of the steps of the particles in x and y
% directions

dx=zeros(NA,d);
switch d
    case 1
        dx=sqrt(kappa)*randn(NA,1);
    case 2
        [eig_vectors,eig_vals]=eig(kappa); % "eig" gives eigen vectors (in a matrix) 
                               %and eigen values (in the diagonal of a matrix)
        xr=sqrt(eig_vals(1,1))*randn(NA,1); % the particle disepersion in the rotated system
        yr=sqrt(eig_vals(2,2))*randn(NA,1);


        dx(:,1)=xr*eig_vectors(1,1)+yr*eig_vectors(2,1);
        dx(:,2)=xr*eig_vectors(1,2)+yr*eig_vectors(2,2);
end

%% check random walk (without advection)
%{

alpha_star=10
Da=0.2
NA=500000;

for dt=0:0.001:0.1
    disp(dt)
    kap_nd=kappa_nd(alpha_star,Da,dt);
    figure(1)
    dxA=random_walk(kap_nd,NA,2);
    edges{1}=-2:0.1:2;
    edges{2}=-2:0.05:2;
    [n,c]=hist3(dxA,'Edges',edges);
    imagesc(c{1},c{2},n')
    set(gca,'ydir','normal')
    axis equal tight
    grid
    set(gca,'ylim',[-2 2],'xlim',[-2 2])
end
%}
%{
%% check random walk without advection
clf
alpha_star=10
Da=5
NA=500000;
x0=0;y0=0;
xA=ones(NA,1)*[x0 y0];

for dt=0:0.01:1
    disp(dt)
    figure(1)
    kap_nd=kappa_nd(alpha_star,Da,dt);
    dxA=shear_flow_random_walk1(kap_nd,NA);
    xnew=xA+dxA+alpha_star*xA(:,2)*[1 0]*dt;
    edges{1}=-2:0.1:5;
    edges{2}=-2:0.1:3;
    [n,c]=hist3(xnew,'Edges',edges);
    imagesc(c{1},c{2},n')
    set(gca,'ydir','normal')
    grid, colorbar
    set(gca,'ylim',[-2 3],'xlim',[-2 5])
    axis equal tight
end
%}
