function [mpA,mpB,flag,sumprxn]=react_v1(d,xA,xB,mpA,mpB,dt,D,Kf,omega,kappa,debug_on,n)
% for each living A particle
%  1. find all B particles (real and image particles) within a rectangle 
%     that bounds the elipse defined by F=s'*(2k)^-1 *s=2a 
%      (Outside the ellipse, probability of reaction drops below a (small)
%      threshold )
%  2. calculate distance vector s to these points
%  3. remove from the list the B particles which are outside the ellipse,
%      i.e. check if  F>2a and if yes remove from list
%  4. Calculate the probability of A+B->C reaction. v_s0*exp(-F/2)
%  5. destroy the respective proportion of the B particles masses.
%  6. destroy part of the A particle mass
%
% n =number of time step


%% initialization
flag=0; % flag for signaling that time step needs to be divided
NA=size(xA,1); % number of particles at current time step beginning

omg2=omega/2;
%translate the locations by -omega/2
xA=xA-omg2;
xB=xB-omg2;
% sort the B particles loation into a kd-tree
% tree=kdtree(xB);
tree=createns(xB,'nsmethod','kdtree', 'BucketSize',60);

% dimension specific constants
switch d
    case 1
        v_s0=1/sqrt(24*D*dt);
        denom=24*D*dt;
        rss=sqrt(24*D*dt);
    case 2
        a=2;
        correction_factor=1/(1-exp(-a));  %about 1.007 for a=5
        v_s0=correction_factor/(2*pi*sqrt(det(2*kappa)));
        k11=kappa(1,1);
        k22=kappa(2,2);
        rss=sqrt(4*a*[k11 k22]); % half length of the rectangle of search 
% can just use:         rss=sqrt(4*a*diag(kappa));

        % (the rectangle which confines the ellipse F=2a, see below)
        ki=(2*kappa)^-1; % the inverse of 2*kappa (for colocation probability evaluation)
        ki11=ki(1,1); ki12=ki(1,2); ki22=ki(2,2);
end   

%% loop over particles

for kA=1:NA % loop over all A particles
   x=xA(kA,:); % the specific A particle coordinates

   % find all B particles (real and image particles) within a hypercube 
   % with hlf length defined by rss vector
   [Bidx,dist,Bn,abs_dist]=neighbour_search_v3(x,xB,tree,rss,omega,omg2,d,debug_on);

   if Bn>0 % if found any
        switch d
           case 1
               v_s=v_s0-abs_dist/denom;
           case 2
               distX=dist(:,1);
               distY=dist(:,2);
               %check if they are within th ellipse, otherwise remove them
               F=ki11*distX.^2 + 2*ki12*distX.*distY + ki22*distY.^2;
               v_s=v_s0*exp(-0.5*F);
               v_s(F>(2*a))=0; % indices of the particles within the ellipse           
       end
       prxn=mpB(Bidx).*v_s*Kf*dt; %multiplication of two vectors (element wise)
       sumprxn=sum(prxn); % the fraction lost from the A particle
       prxnA=mpA(kA)*v_s*Kf*dt;  % this is the fraction lost from all relevant B particles
       if sumprxn>1
           warning(['total reaction ratio was ' num2str(sumprxn) ...
                  ', exceeding 1. try making smaller time steps'])
              disp(['In time step ' num2str(n)])
           flag=1; % this flag marks to the calling function that the total rxn 
            % ratio exceeded one. The calling function will cancel this time step
            % and try making it by two time steps with half the length
           break;
       end
       mpA(kA)=mpA(kA)*(1-sumprxn);   
       mpB(Bidx)=mpB(Bidx).*(1-prxnA);
    end % if Bn>0
end % for kA