function [mpA1,mpB1,xA1,xB1,sumpr]=recursive_walk_and_react(alpha,D,dt,d,Kf,omega,av,xA,xB,NA,NB,mpA,mpB,n,sumpr)
    %% first, move the particles by brownian motion
    % calculate a random walk step for each particle and add this to their location
    kappa1=kappa(alpha,D,dt,d); % kappa matrix of shear dispersion
    
    % calculate drift
    if d==1
        driftA=0; driftB=0;
    elseif d==2        
        e1=[1 zeros(1,d-1)]; % unit vector in x direction
        driftA=alpha*xA(:,2)*e1*dt; % since U= alpha* y and x=Udt
        driftB=alpha*xB(:,2)*e1*dt;        
    else
        error('still not 3d')
    end
    
    %change location of particles by random walk and drift
    xA1=rwaa(xA,kappa1,NA,d,driftA,omega);
    xB1=rwaa(xB,kappa1,NB,d,driftB,omega);
   
    % now react between particles
    
    
    if av.integrated
        [mpA1,mpB1,flag,sumprxn]=...
            react_int(d,xA1,xB1,mpA,mpB,dt,D,Kf,omega,kappa1,av.debug_on,n);
    else
        [mpA1,mpB1,flag,sumprxn]=...
            react_v2(d,xA1,xB1,mpA,mpB,dt,D,Kf,omega,kappa1,av.debug_on,n);
    end
    % check if during 'react' run, there was an instance of prxn>1
    if flag==1 % since this happenned, we split the time step to two, get 
        % rid of the old data and create new data based on recursive
        % calculation of walk+drift+react.
        if sumpr(n)==0
            sumpr(n)=sumprxn;
        end
        clear xA1 xB1 mpA1 mpB1 % this line can be commented
        [mpA1,mpB1,xA1,xB1]=recursive_walk_and_react(alpha,D,dt/2,d,Kf,omega,av,xA, xB, NA,NB,mpA, mpB ,n,sumpr);
        [mpA1,mpB1,xA1,xB1]=recursive_walk_and_react(alpha,D,dt/2,d,Kf,omega,av,xA1,xB1,NA,NB,mpA1,mpB1,n,sumpr);
    end
    
    function xA=rwaa(xA,kappa1,NA,d,driftA,omega)
       dxA=random_walk(kappa1,NA,d); % the size of the move (NXd) due to random walk
       xA=xA+dxA+driftA;  %           
       xA=mod(xA,omega); % if a particle was moved out of the domain by the brownian motion, it bounces back to the domain at the other boundary 
                           % (we assume periodic boundary conditions)
       
    