% defining run parameters by the user
function [av,d,Nsim,D,Kf,C_0,omega,N_0,alpha,T,...
          t_mult,dt0,max_dt,nos,t,dt,mp0]=set_run_parameters
  %% administrative definitions
  % av stands for Administritive Variables.
    av.plot_conc=1; % flag. when equal 1, plot of c(t) will be created when run ends
    av.plot_conc_now=1; % flag. when equal 1, c(x) plots will be created during run 
    av.save_conc_plot=0; %flag, when equal 1, c(x) plots will be saved as png files
    av.plot_conc_nowB=1; % flag, whether B should be plotted as well
    av.TBDM=20;              %  time between displaying massage about run (seconds)
    av.TBP=10;              % time between plotting (seconds)
    av.save_master_file_flag=1; % flag. when equal 1, master file 
                                % will be saved at the end of the
                                % simulation run
    %   av.tstbs=0;              % indices of time steps that should be saved
    av.runs_folder=sifn('runs'); % folder to store files
    av.debug_on=0;
    av.integrated=0; % flag, when equal 1, colocation will be integrated over time step

  %% run parameters
    d=1%2; % number of dimensions. can be 1,2
    Nsim=1; %number of simulations (realizations)
    D=0.005; % dispersion coefficient
    Kf=0.5; % reaction rate
    C_0=4; %initial concentration for both species (A,B)
    omega=128;%1; % domain length (so that domain volume is omega^d)
    N_0=10^3;%10^3; %256000;  initial number of A particles
              % (equal to  initial number of B particles)
    alpha=0; % shear rate constant 
    T=100/(Kf*C_0); % maximum value of time to be reached
    t_mult=1.025; %multiplier of time step
    dt0=0.025; % initial time step
    max_dt=0.1; % maximum time step

  %% calculate resulting parameters
    [nos,max_dt_pr,t,dt]=chk_nos(dt0,t_mult,T,max_dt); % nos - number of time steps
        % max_dt_pr - the maximum time step in the simulation
        % t - a vector of length nos+1. 
        %            contains the discrete values of time that are to be simulated.
        % dt - time step size (vector of nos length)
    
    mp0= omega^d*C_0/N_0;  % mp0 = initial mass of particle
    
    % get the indices of the time steps 
    % when system state is to be saved
    av.tstbs=tsn(t*Kf*C_0,[0 1 10 100]); 
    av.tstbs=[av.tstbs nos]; %save the last time step as well

%% make a new directory for saving data/results    
    if isunix, av.slash='/'; else av.slash='\'; end %slash for Unix/Win OS
    % create a new directory to save results
    av.run_number=1; % initial guess
    av.sim_folder=[av.runs_folder  num2str(av.run_number) av.slash];
    while exist(av.sim_folder,'dir')==7 % if this directory already exists
        av.run_number=av.run_number+1;             % advance the counter
        av.sim_folder=[av.runs_folder num2str(av.run_number) av.slash ];  % and update folder name
    end % until the folder name is NOT existing
    mkdir(av.sim_folder)  % then, create it
%% open a log file
    diary([av.sim_folder 'log.txt']) % create a log file. all screen output 
                                     % will be recorded in the log.
%% display message, create a figs folder, save parameters to file
    disp(datestr(now))
    disp(['Run number #' num2str(av.run_number) ...
        '. Data & Results will be saved to new folder'])
        disp(av.sim_folder)
    av.fig_folder=[av.sim_folder 'figs' av.slash];
    mkdir(av.fig_folder)
    
    av.master_results_file_name=[av.sim_folder  'results.mat'];
    
    
    av.input_file_name=[av.sim_folder 'input.mat'];
    save(av.input_file_name)
    disp('Saved run parameters/input to file: ')
        disp(av.input_file_name)
end

function tstbs=tsn(t_vector,time_points)
% function which determines the indices of time (t_vector) approximately associated with times
% points (time_points)
    k=1;
    for i=1:length(time_points)
        ti=find(t_vector>=time_points(i));
        if ~isempty(ti)
            tstbs(k)=ti(1); % just take the first value found 
            k=k+1; % advance counter
        end
    end
    if k==1  % if none where found, retun 0
        tstbs=0;
    end                
end